<?php

/**
 * Controller for Wizard
 *
 **/
class Wizard_Controller extends Authenticated_Controller
{
	/**
	 * Default view
	 *
	 * @param $view string
	 * @return void
	 **/
	public function index($view = false) {
		if (!wizard_helper::authorized_for_wizard()) {
			return url::redirect('wizard/unauthorized');
		}
		if (!wizard_helper::preconditions()) {
			return url::redirect('wizard/preconditions_failed');
		}
		if(!$view) {
			$view = 'host_wizard';
		}
		// Disable keycommands for the wizard
		$this->template->keycommands_disabled = true;
		// This page should never refresh itself
		$this->template->disable_refresh = true;
		// Create a custom header? Is it needed? This prevents the normal menu from rendering
		$this->template->hide_header = true;
		// Prevent dojo from loading
		$this->template->no_dojo = true;
		// Set page content
		$this->template->content = $this->add_view($view);
		// Sets appropriate page title. Depends on naming of the view file, i.e host_wizard.php
		$this->template->title = _(ucwords(str_replace('_', ' ', $view)));
		// Add extra js and css headers
		$this->template->js_header = $this->add_view('js_header');
		$this->template->css_header = $this->add_view('css_header');
		// Reset all css rules
		$this->template->css[] = 'modules/wizard/media/css/bootstrap.css';
		$this->template->css[] = 'modules/wizard/media/css/bootstrap-responsive.css';
		$this->template->css[] = 'modules/wizard/media/css/bootstrap-wizard.css';
		$this->template->css[] = 'modules/wizard/media/css/wizard.css';

		$this->template->js[] = 'modules/wizard/media/js/bootstrap.js';
		$this->template->js[] = 'modules/wizard/media/js/bootstrap-wizard.js';
		$this->template->js[] = 'modules/wizard/media/js/'.$view.'.js';

		// Get setting whether introduction should be skipped and redirection should be made
		$this->template->content->skip_intro = (int)(bool) config::get('wizard.skip-intro', '*');
	}

	/**
	 * Saves a ninja user setting
	 *
	 * @return string
	 **/
	public function save_ninja_setting() {
		if(!isset($_POST['setting']) ||
			$_POST['setting'] !== 'skip-intro' ||
			!isset($_POST['value'])) {
			return json::fail("Missing valid setting");
		}

		$save_success = Ninja_setting_Model::save_page_setting(
			'wizard.' . $_POST['setting'],
			'*',
			(int)(bool) $_POST['value'],
			Auth::instance()->get_user()->get_username()
		);

		if (!$save_success) {
			return json::fail("Failed saving user setting");
		}
		json::ok("Setting successfully saved");
	}

	/**
	 * User is not authorized to use the wizard
	 *
	 * @return void
	 **/
	public function unauthorized() {
		$this->template->content = $this->add_view('unauthorized');
		$this->template->disable_refresh = true;

		$this->template->content->error_message = _('It appears as though you do not have permission to use the wizard');
		$this->template->content->error_description = _('If you believe this is an error, contact your administrator to give you sufficient authorization.');
	}

	/**
	 * Preconditions to use the wizard failed
	 *
	 * @return void
	 **/
	public function preconditions_failed() {
		$this->template->content = $this->add_view('unauthorized');
		$this->template->disable_refresh = true;

		$this->template->content->error_message = _('Preconditions to use the wizard is not met');
		$this->template->content->error_description = _('Make sure that auth_method ninja is set to true in http_api.yml');
	}

} // END class Wizard_Controller
